---
title: <span class="badge object-type-scalar"></span> AmpereHour
---
# <span class="badge object-type-scalar"></span> AmpereHour

Energy: Ampere-hour (Ah)

## Definition

```python
# Energy: Ampere-hour (Ah)
AmpereHour: typing.Literal["amph"] = "amph"
```
